# Changelog

## 0.19.1 (2026-03-24)

Full Changelog: [v0.19.0...v0.19.1](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.19.0...v0.19.1)

### Chores

* **internal:** update gitignore ([b4627a7](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b4627a799871d5ab98a875b7d62e0ed217cd539b))

## 0.19.0 (2026-03-23)

Full Changelog: [v0.18.0...v0.19.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.18.0...v0.19.0)

### Features

* **api:** api update ([89a61b0](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/89a61b06cd4ee62d510a7487ee70e6e4559242cd))
* **api:** api update ([75ce6dd](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/75ce6dd1a4462e79348dd4bc62bc46d7400a235b))
* **api:** manual updates ([3cb88e8](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/3cb88e84c8db05d65d4250968f63fa349fc12aa4))
* **api:** manual updates ([254767b](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/254767bcf476b3ec0221ec56772053b7c01d59a1))

## 0.18.0 (2026-03-20)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.17.0...v0.18.0)

### Features

* **api:** api update ([d3605d6](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/d3605d653116f982d2790f63e18b33f349decbdc))
* **api:** api update ([aa09964](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/aa09964b85791ec82316a5da9229cb423efa496d))


### Bug Fixes

* **deps:** bump minimum typing-extensions version ([6860af5](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/6860af59921a30513358ac7715c30d6db22c0e1e))
* **pydantic:** do not pass `by_alias` unless set ([a022ba5](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/a022ba5a009dded7f0f52a22b4123844bc2dae6d))
* sanitize endpoint path params ([0234463](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/023446352196db43272826c475c9d05ea38c815c))


### Chores

* **internal:** tweak CI branches ([47c7ece](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/47c7ece7a3e53c2e613b9613a2e9d24344df1b98))

## 0.17.0 (2026-03-13)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([80e580c](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/80e580c870ef94b1224761c4f860a7833b11a403))

## 0.16.0 (2026-03-11)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.15.0...v0.16.0)

### Features

* **api:** api update ([3cab202](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/3cab202709686fe588d8d5beed5f779cbb0045ea))
* **api:** api update ([adecb75](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/adecb75a594a44b99238eac9d8bf9fd8d1a74393))
* **api:** manual updates ([3b4643c](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/3b4643ccad434c2727ac718cc0f93e10348d587d))

## 0.15.0 (2026-03-09)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([a443d8a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/a443d8a3c7dce7c42f0343086468ce8321a2e1bd))
* **api:** api update ([94de8a3](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/94de8a3e31ccba7e26cf32a17dd6568cdb09fb7d))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([97ffb6a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/97ffb6aebe5cdba74303cf0769a63ed3ccf6c621))

## 0.14.0 (2026-03-05)

Full Changelog: [v0.13.5...v0.14.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.5...v0.14.0)

### Features

* **api:** api update ([cbb2834](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/cbb28343c2f70475ca20b9ef9bd514ab3cc90041))
* **api:** manual updates ([7c7e047](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/7c7e047186885068f1af52ed36737e55ba9b672e))

## 0.13.5 (2026-03-04)

Full Changelog: [v0.13.4...v0.13.5](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.4...v0.13.5)

## 0.13.4 (2026-03-03)

Full Changelog: [v0.13.3...v0.13.4](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.3...v0.13.4)

## 0.13.3 (2026-03-03)

Full Changelog: [v0.13.2...v0.13.3](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.2...v0.13.3)

## 0.13.2 (2026-03-03)

Full Changelog: [v0.13.1...v0.13.2](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.1...v0.13.2)

## 0.13.1 (2026-03-03)

Full Changelog: [v0.13.0...v0.13.1](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.13.0...v0.13.1)

## 0.13.0 (2026-03-02)

Full Changelog: [v0.12.1...v0.13.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.12.1...v0.13.0)

### Features

* **api:** api update ([2d65cc7](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/2d65cc7cca2a03c18e7a82c6ebca38b86af528ad))
* **realtime:** add WebSocket realtime resource for gateway streaming ([cf9832f](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/cf9832fc25a7266720b1e7faa57eb5e827160ceb))


### Chores

* **internal:** make `test_proxy_environment_variables` more resilient to env ([9871aac](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/9871aac2eb95dd73ad50179ef54c8735c1823b00))

## 0.12.1 (2026-02-25)

Full Changelog: [v0.12.0...v0.12.1](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.12.0...v0.12.1)

### Bug Fixes

* **data:** fix content_type validation and upload timeouts in ingest ([f9b9261](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/f9b9261c414c90da5e5ef745e94b28a23277a182))

## 0.12.0 (2026-02-25)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.11.0...v0.12.0)

### Features

* **api:** api update ([ad42a5a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/ad42a5aebced2a9eb6607ad5abe5e183e93f23ba))
* **api:** api update ([c2eee37](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/c2eee37adf2090b30bba1d45c5ade2248a674bab))
* **api:** api update ([8dc53b0](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/8dc53b04a785a0521b3592c5eb9c154320e30217))
* **api:** manual updates ([b707cbc](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b707cbc862f763c64953dbe61788ad88b7e0a57f))
* **data:** support file paths and URLs in ingest payload ([0592f80](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/0592f80d7b89c771226eb22ad29abd61976a35bc))


### Bug Fixes

* **data:** remove unused import in upload url response type ([6993ab8](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/6993ab895ce2c43ab3fc777e957dfe0e8adaccfd))
* **data:** resolve pyright type errors in ingest method ([c14cbb2](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/c14cbb2633e96107dfd5eea6743d66a88ce21c34))


### Chores

* format all `api.md` files ([35faf4b](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/35faf4b286f21fa3bbea36cc5a85e28ea81a8a6d))
* **internal:** add request options to SSE classes ([cd7a095](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/cd7a095dcd414274e63ee6279c05bf6bbff5fc8a))
* **internal:** bump dependencies ([f68ecde](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/f68ecdeb0dd3b05c53508833931680160ef5c04c))
* **internal:** fix lint error on Python 3.14 ([652f0fb](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/652f0fb8ac711386a040cb393c7fede49e30837a))
* **internal:** make `test_proxy_environment_variables` more resilient ([7a3b8ee](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/7a3b8eedf434b16b9620821967beca4326209e3d))
* **internal:** remove mock server code ([115392a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/115392a7cdccf2d01c538238d85b0edbd4e5401f))
* update mock server docs ([777b04b](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/777b04be504dd2e1d9baec98fce11fca1e08d022))

## 0.11.0 (2026-02-09)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.10.0...v0.11.0)

### Features

* **api:** api update ([9849923](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/9849923342eb2812d382c73fb14147be25df7159))
* **api:** manual updates ([fdd2c17](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/fdd2c17b541355f32ea65c3d14eb0933885b818f))
* **api:** manual updates ([b85f9a1](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b85f9a1eeb0191852aaed9ecb0bdee714e5bd7ed))
* **client:** add custom JSON encoder for extended type support ([1b1970d](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/1b1970dc68185dcdf6d0d94149b1aa151595ff98))

## 0.10.0 (2026-01-29)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([61e75a6](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/61e75a6c2e2f591c5659c8e429672c04485dbc75))
* **api:** api update ([80cef83](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/80cef835430a185c37646749ea0452e0f5ece203))

## 0.9.0 (2026-01-26)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.8.0...v0.9.0)

### Features

* **api:** api update ([b14e4b0](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b14e4b01337ebdbc656bcd405b60eab9267aebb3))
* **api:** api update ([aa93942](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/aa93942ad5991de2a5fccc42fb7d26ad6ecf84ea))


### Chores

* **ci:** upgrade `actions/github-script` ([3d9756c](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/3d9756c3ab8c348f1dbbaca897d4c1220a9a7b93))

## 0.8.0 (2026-01-21)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.7.0...v0.8.0)

### Features

* **api:** api update ([0996f7d](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/0996f7d53826b0c8e7ba4669e98f7440a93e337f))
* **api:** manual updates ([d312abd](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/d312abde58f65b07278901c9cf734eb06a711e39))
* **client:** add support for binary request streaming ([2341d22](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/2341d229279f4daa846b64d6903d2c266f980675))


### Bug Fixes

* use async_to_httpx_files in patch method ([d336a2e](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/d336a2e3294f69af761adb7b0b23215aa49d51de))


### Chores

* **internal:** add `--fix` argument to lint script ([4f1c89a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/4f1c89aaabcbbc08ec568fe33e989f0049ebe755))
* **internal:** add missing files argument to base client ([26a0750](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/26a0750857142de33ab48c5c33d0f0cfc61d006f))
* **internal:** codegen related update ([b67a89e](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b67a89ef631a9803775da8826cd15ede8e044d1f))
* **internal:** update `actions/checkout` version ([777d999](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/777d9998a8b53b31034f1828bd560051fe01490f))
* speedup initial import ([1554754](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/15547548a598a3c5cbdfa8f16edc98275661afc4))

## 0.7.0 (2025-12-10)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([70750c2](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/70750c2e41b5f0573ef864b70c74ba369aa07a4e))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([afbb39d](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/afbb39dea42c974c8e4b94d69d773a5feb2e30c9))


### Chores

* add missing docstrings ([5f030dd](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/5f030ddb86bf5ebda28d31716002a20a645c4a09))
* **docs:** use environment variables for authentication in code snippets ([3826b97](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/3826b970f56bb2300346d1e1807dd2a19760f91e))
* update lockfile ([675b015](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/675b015b3eec8f12d99699f2b7b5b9e3f72effbf))

## 0.6.0 (2025-12-02)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.5.0...v0.6.0)

### Features

* **api:** manual updates ([f8c968a](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/f8c968a1fd82c219debc9c537f21be860cc8f7fb))


### Bug Fixes

* ensure streams are always closed ([60ac39d](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/60ac39df028f9f4b0ee180c4faeb017392557c88))


### Chores

* add Python 3.14 classifier and testing ([628acbc](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/628acbcfa9cd4532dcab07a46d2a006da65f85ab))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([5c56d92](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/5c56d92cd03f9d2cc935d0118405d04d9bf5bb0a))

## 0.5.0 (2025-11-17)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([b1fcbd8](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b1fcbd823d9bf5000c0626c598830a23ab2bcb7a))
* **api:** api update ([6a8b0d0](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/6a8b0d042c95360a1d871a3ad2fb5e4ec6b1295a))
* **api:** manual updates ([9db0c86](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/9db0c86a3ec44f6fb349f4502ae376b97d65968d))


### Bug Fixes

* compat with Python 3.14 ([808f6b0](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/808f6b07bbe32ffc705a5419c17c7862de67799f))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([b8eee50](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/b8eee509abf2bb51c2f3b37af1f6cd2f789247a7))


### Chores

* **package:** drop Python 3.8 support ([faaa46f](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/faaa46fd3cea5183eed63b484b276649b461c382))

## 0.4.0 (2025-11-05)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/ElicitLabs/elicitlabs-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([0818987](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/0818987037d4e3386070e610340acd320081fc91))


### Chores

* update SDK settings ([70d0789](https://github.com/ElicitLabs/elicitlabs-python-sdk/commit/70d07899aa34ad2e85281141bb9e732365be7571))

## 0.3.0 (2025-11-05)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/ElicitLabs/modal-python-sdk/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([8bd3668](https://github.com/ElicitLabs/modal-python-sdk/commit/8bd366885e229a8c5d441cde63d8c3a619314d93))
* **api:** api update ([f29b786](https://github.com/ElicitLabs/modal-python-sdk/commit/f29b78675d71ee2dac399cd3f4d82d9dff051852))
* **api:** manual updates ([ba6ef0a](https://github.com/ElicitLabs/modal-python-sdk/commit/ba6ef0a31e3813ebb4e8b6fe225454feaee3547e))


### Bug Fixes

* **client:** close streams without requiring full consumption ([27a0353](https://github.com/ElicitLabs/modal-python-sdk/commit/27a03536d288096908e367425972b75644efb436))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([afa3e51](https://github.com/ElicitLabs/modal-python-sdk/commit/afa3e51305524e93d3360ddaafde1441a8bdf308))
* do not install brew dependencies in ./scripts/bootstrap by default ([e6ffca9](https://github.com/ElicitLabs/modal-python-sdk/commit/e6ffca92643caf732e6beb205a9b713f21ae7dfd))
* **internal/tests:** avoid race condition with implicit client cleanup ([1967ee1](https://github.com/ElicitLabs/modal-python-sdk/commit/1967ee1c2e31d221f21b2088b37978e0198b9881))
* **internal:** codegen related update ([b3f7c70](https://github.com/ElicitLabs/modal-python-sdk/commit/b3f7c70f00076fb991fc1420a7de54f6d8c5281b))
* **internal:** detect missing future annotations with ruff ([03e4e51](https://github.com/ElicitLabs/modal-python-sdk/commit/03e4e5109d7cba6b2b16b15a75f24d2de6cf1690))
* **internal:** grammar fix (it's -&gt; its) ([8167d88](https://github.com/ElicitLabs/modal-python-sdk/commit/8167d88a50a836585ac5ce2568d1080f90dc35ef))
* **internal:** update pydantic dependency ([e27bd49](https://github.com/ElicitLabs/modal-python-sdk/commit/e27bd490de9263f1a5121ed5011bc9b504056376))
* **types:** change optional parameter type from NotGiven to Omit ([ece45db](https://github.com/ElicitLabs/modal-python-sdk/commit/ece45db796e756a686544330335fbe7965c8fa0f))

## 0.2.0 (2025-09-06)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/ElicitLabs/modal-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([29ef4d5](https://github.com/ElicitLabs/modal-python-sdk/commit/29ef4d55e71b8c6bcb31d99136241d3cc531f2f6))
* **api:** manual updates ([b25a157](https://github.com/ElicitLabs/modal-python-sdk/commit/b25a157233997452f3c82dbd6b16492e8b9894dd))
* improve future compat with pydantic v3 ([b278a4f](https://github.com/ElicitLabs/modal-python-sdk/commit/b278a4faf1edbfd3637955d45312e6fa6320faa7))


### Chores

* **internal:** move mypy configurations to `pyproject.toml` file ([3863623](https://github.com/ElicitLabs/modal-python-sdk/commit/3863623680a802829f8f8f6d2282fea29c3f7ac7))

## 0.1.0 (2025-09-03)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/ElicitLabs/modal-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** update via SDK Studio ([373dbce](https://github.com/ElicitLabs/modal-python-sdk/commit/373dbceed8aa5cde59951b759c737f31c34ab81c))
* **api:** update via SDK Studio ([2178bdf](https://github.com/ElicitLabs/modal-python-sdk/commit/2178bdff85ce23510c4fbaf1bb1475eeae293d0d))


### Chores

* update SDK settings ([0e0d556](https://github.com/ElicitLabs/modal-python-sdk/commit/0e0d556f761aa830ed1008eafe5789dafc5dab80))
* update SDK settings ([36952f0](https://github.com/ElicitLabs/modal-python-sdk/commit/36952f0edb8bda863589bb4c126d1217d36a91d1))
